basicco package
===============

.. automodule:: basicco
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   basicco.abstract_class
   basicco.caller_module
   basicco.context_vars
   basicco.custom_repr
   basicco.data_class
   basicco.default_dir
   basicco.dynamic_class
   basicco.dynamic_code
   basicco.explicit_hash
   basicco.fabricate_value
   basicco.get_mro
   basicco.hash_cache_wrapper
   basicco.implicit_hash
   basicco.import_path
   basicco.init_subclass
   basicco.locked_class
   basicco.mangling
   basicco.mapping_proxy
   basicco.named_tuple
   basicco.namespace
   basicco.obj_state
   basicco.qualname
   basicco.recursive_repr
   basicco.runtime_final
   basicco.safe_not_equals
   basicco.safe_repr
   basicco.set_name
   basicco.type_checking
   basicco.unique_iterator
   basicco.weak_reference
